@@ -2,6 +2,7 @@ import json
 import logging
 import sys
 import uuid
+from confire import Configuration
 
 import re
 import os
@@ -17,9 +18,10 @@ from twisted.python import log
 
 class ApiRpcClient(object):
 
-    def __init__(self, host='0.0.0.0', port=7080):
+    def __init__(self, host='0.0.0.0', port=7080, settings=None):
         self.host = host
         self.port = port
+        self.settings = settings
 
     @inlineCallbacks
     def start_task(self, task, **kwargs):
@@ -30,7 +32,7 @@ class ApiRpcClient(object):
     def _remote_exec(self, task_name, on_result, *args, **kwargs):
         from mfcloud.remote import Client, Task
 
-        client = Client(host=self.host)
+        client = Client(host=self.host, settings=self.settings)
         try:
             yield client.connect()
 
@@ -42,13 +44,14 @@ class ApiRpcClient(object):
 
                 res = yield task.wait_result()
                 on_result(res)
+
             except Exception as e:
                 print('Failed to execute the task: %s' % e.message)
 
         except ConnectionRefusedError:
             print 'Can\'t connect to mfcloud server'
 
-        reactor.stop()
+        client.shutdown()
 
     #
     #
@@ -284,6 +287,21 @@ class ApiRpcClient(object):
 
         self._remote_exec('publish', self.on_print_list_result, self.format_domain(domain, ssl), app)
 
+    def on_vars_result(self, data):
+        x = PrettyTable(["variable", "value"], hrules=ALL)
+        for line in data.items():
+            x.add_row(line)
+        print x
+
+    def set(self, name, val, **kwargs):
+        self._remote_exec('set_var', self.on_vars_result, name, val)
+
+    def unset(self, name, **kwargs):
+        self._remote_exec('rm_var', self.on_vars_result, name)
+
+    def vars(self, **kwargs):
+        self._remote_exec('list_vars', self.on_vars_result)
+
     def unpublish(self, domain, ssl=False, **kwargs):
 
         def on_result(data):
@@ -360,7 +378,7 @@ class ApiRpcClient(object):
 
         def on_result(result):
 
-            os.system("docker run -i -t -v %(hosts_vol)s --volumes-from=%(container)s %(image)s %(command)s" % {
+            os.system("docker run -i -t -v %(hosts_vol)s --dns=%(dns-server)s --dns-search=%(dns-suffix)s --volumes-from=%(container)s %(image)s %(command)s" % {
                 'container': '%s.%s' % (service, app),
                 'image': result['image'],
                 'hosts_vol': '%s:/etc/hosts' % result['hosts_path'],
@@ -418,6 +436,18 @@ def populate_client_parser(subparsers):
     cmd.add_argument('--ssl', default=False, action='store_true', help='Ssl protocol')
     cmd.set_defaults(func='publish')
 
+    cmd = subparsers.add_parser('set', help='Set environment variable on server')
+    cmd.add_argument('name', help='Variable name')
+    cmd.add_argument('val', help='Value')
+    cmd.set_defaults(func='set')
+
+    cmd = subparsers.add_parser('unset', help='Unset environment variable on server')
+    cmd.add_argument('name', help='Variable name')
+    cmd.set_defaults(func='unset')
+
+    cmd = subparsers.add_parser('vars', help='List environment variables on server')
+    cmd.set_defaults(func='vars')
+
     cmd = subparsers.add_parser('unpublish', help='Unpublish an application')
     cmd.add_argument('domain', help='Domain to unpublish')
     cmd.add_argument('--ssl', default=False, action='store_true', help='Ssl protocol')
@@ -441,6 +471,11 @@ def populate_client_parser(subparsers):
     cmd.add_argument('service', help='Service name')
     cmd.set_defaults(func='inspect')
 
+    cmd = subparsers.add_parser('cert-gen', help='Inspect application service')
+    cmd.add_argument('username', help='Your username')
+    cmd.add_argument('service', help='Service name')
+    cmd.set_defaults(func='inspect')
+
     cmd = subparsers.add_parser('dns', help='List dns records')
     cmd.set_defaults(func='dns')
 
@@ -535,9 +570,6 @@ def main(argv):
 
     arg_parser = get_argparser()
 
-
-
-
     args = arg_parser.parse_args()
 
 
@@ -546,7 +578,27 @@ def main(argv):
 
     args.argv0 = argv[0]
 
-    client = ApiRpcClient(host=args.host)
+
+    class SslConfiguration(Configuration):
+        enabled = False
+        key = '/etc/mfcloud/ssl.key'
+        cert = '/etc/mfcloud/ssl.crt'
+
+    class MyAppConfiguration(Configuration):
+
+        CONF_PATHS = [
+            '/etc/mfcloud/mfcloud-client.yml',
+            # os.path.expanduser('~/.myapp.yaml'),
+            # os.path.abspath('conf/myapp.yaml')
+        ]
+
+        haproxy = False
+
+        ssl = SslConfiguration()
+
+    settings = MyAppConfiguration.load()
+
+    client = ApiRpcClient(host=args.host, settings=settings)
 
     if isinstance(args.func, str):
         log.msg('Starting task: %s' % args.func)
